@@ -35,18 +35,20 @@ gbif <- function(genus, species='', geo=TRUE, sp=FALSE, removeZeros=TRUE, downlo
 		cbind(tax, ans)
 	}
 
-
+	
 	genus <- trim(genus)
-	spec <- species
+	species <- trim(species)
+	gensp <- paste(genus, species)
+	species <- gsub("   ", " ", trim(species)) 
+	species <- gsub("  ", " ", trim(species)) 	
 	species <- gsub(" ", "%20", trim(species))  # for genus species var. xxx
+    species <- paste(genus, '+', species, sep='')
 	
 	if (sp) geo <- TRUE
-
-    spec <- paste('scientificname=', genus,'+', species, sep='')
 	if (geo) { cds <- '&coordinatestatus=true' 
 	} else { cds <- '' }
     base <- 'http://data.gbif.org/ws/rest/occurrence/'
-    url <- paste(base, 'count?', spec, cds, sep='')
+    url <- paste(base, 'count?scientificname=', species, cds, sep='')
     x <- readLines(url, warn=FALSE)
     x <- x[substr(x, 1, 20) == "<gbif:summary totalM"]
     n <- as.integer(unlist(strsplit(x, '\"'))[2])
@@ -54,11 +56,11 @@ gbif <- function(genus, species='', geo=TRUE, sp=FALSE, removeZeros=TRUE, downlo
 	if (! download) { return(n) }
 	
     if (n==0) {
-		cat(genus, spec, ': no occurrences found\n')
+		cat(gensp, ': no occurrences found\n')
         return(invisible(NULL))
     } else {
 		if (feedback > 0) {
-			cat(genus, spec, ':', n, 'occurrences found\n')
+			cat(gensp, ':', n, 'occurrences found\n')
 			flush.console()
 		}
 	}
@@ -75,7 +77,7 @@ gbif <- function(genus, species='', geo=TRUE, sp=FALSE, removeZeros=TRUE, downlo
 			flush.console()
 		}
 		
-        aurl <- paste(base, 'list?', spec, '&mode=processed&format=darwin&startindex=', format(start, scientific=FALSE), cds, sep='')
+        aurl <- paste(base, 'list?scientificname=', species, '&mode=processed&format=darwin&startindex=', format(start, scientific=FALSE), cds, sep='')
 		zz <- gbifxmlToDataFrame(aurl)
 
 		#s <- readLines(aurl, warn=FALSE)
@@ -148,5 +150,6 @@ gbif <- function(genus, species='', geo=TRUE, sp=FALSE, removeZeros=TRUE, downlo
 
 #sa <- gbif('solanum')
 #sa <- gbif('solanum', '*')
-#sa <- gbif('solanum', 'tuberosum')
+#sa <- gbif('solanum', 'acaule')
+#sa <- gbif('solanum', 'acaule var acaule')
 
